# Survey

Display a survey to the user.

## Example: Likert

A prompt is displayed to the user with a question and a Likert scale.

## Example: Multiple Choice

A prompt is displayed to the user with a question and multiple choice answers.

## Example: Free Text

A prompt is displayed to the user with a question and a free text input.